import os
import requests
import yaml


def load_group_config_for(file):
    group_yaml = os.path.join(get_ocp_build_data_dir(file), 'group.yml')
    return yaml.safe_load(open(group_yaml).read())


def get_ocp_build_data_dir(file):
    return os.path.normpath(os.path.join(os.path.dirname(file), '..'))


def get_artifact_type(file):
    if 'images/' in file:
        return 'image'

    if 'rpms/' in file:
        return 'rpm'

    return '???'


def get_valid_streams_for(file):
    streams_yaml = os.path.join(get_ocp_build_data_dir(file), 'streams.yml')
    return set(yaml.safe_load(open(streams_yaml).read()).keys())


def get_valid_member_references_for(file):
    images_dir = os.path.join(get_ocp_build_data_dir(file), 'images')
    return set([os.path.splitext(img)[0] for img in os.listdir(images_dir)])


def resource_exists(url):
    return 200 <= requests.head(url).status_code < 400


def resource_is_reacheable(url):
    try:
        requests.head(url)
        return True
    except requests.exceptions.ConnectionError:
        return False



from __future__ import print_function
import sys

from . import format, support, schema, github, distgit


def main():
    file = sys.argv[1]

    print('Validating {}'.format(file))

    (parsed, err) = format.validate(open(file).read())
    if err:
        print('{} is not a valid YAML'.format(file), file=sys.stderr)
        print('Returned error: {}'.format(err), file=sys.stderr)
        exit(1)

    err = schema.validate(file, parsed)
    if err:
        print('schema mismatch: {}'.format(file), file=sys.stderr)
        print('Returned error: {}'.format(err), file=sys.stderr)
        exit(1)

    group_cfg = support.load_group_config_for(file)

    (url, err) = github.validate(parsed, group_cfg)
    if err:
        print('GitHub validation failed for {}'.format(url), file=sys.stderr)
        print('Returned error: {}'.format(err, file=sys.stderr))
        exit(1)

    (url, err) = distgit.validate(file, parsed, group_cfg)
    if err:
        print('DistGit validation failed for {}'.format(url), file=sys.stderr)
        print('Returned error: {}'.format(err, file=sys.stderr))
        exit(1)
